@@ -1,5 +1,10 @@
 #!/usr/bin/env python
 
+#
+# 2014-04-03
+#   readh : debug 
+#           it failed in reading TIME_LT of DARK frames. 
+#           fixed not to try to read TIME_LT of DARK frames  
 #
 # 2014-04-02
 #   readh : debug 
@@ -46,11 +51,12 @@ def readh(date, okey):
                 hdunum = 1
             else:
                 hdunum = 0
+
             hdr = pyfits.getheader(rfile, hdunum)
             object = hdr['OBJECT']
-            timelthh = int(hdr['TIME_LT'][:2])
 
             if object == okey:
+                timelthh = int(hdr['TIME_LT'][:2])    #   modified 2014-04-03 
                 fflag += 1
                 if timelthh > 15 and timelthh < 22:
                     print >> foe, file
