@@ -1,8 +1,8 @@
 #include <stdio.h>
 
-void iswap(short xx[], int i, int j);
+void iswap(int xx[], int i, int j);
 
-void qckisort(short xx[], int left, int right)
+void qckisort(int xx[], int left, int right)
 {
   int    i,j;
   int    pivot;
@@ -25,7 +25,7 @@ void qckisort(short xx[], int left, int right)
 
 }
 
-void iswap(short xx[], int i, int j)
+void iswap(int xx[], int i, int j)
 {
   int temp;
   
