@@ -2,6 +2,7 @@
 
 #
 # 2014-02-07 the contour interval has been changed from 0.02 to 0.01 at L114-115
+# 2014-03-10 coped with the bug in matplotlib.pyplot.clf() for mac that replot is not available 
 #
 
 import os
@@ -11,6 +12,7 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
 import math
+import re
 
 
 def findsuffix(date, num1, num2):
@@ -108,6 +110,13 @@ if __name__ == "__main__":
     combdata = fimg[0].data
     fimg.close()
 
+    # for the matplotlib bug for macosx
+    mac = 0
+    for item in os.uname():
+        if re.search('Darwin', item):
+            mac = 1
+            break
+
     fig = plt.figure(facecolor='white', figsize=(10, 8))
     ax1 = fig.add_subplot(111)
     ax2 = fig.add_axes([0.85, 0.11, 0.03, 0.78])   #  [left, bottom, width, height]
@@ -149,7 +158,13 @@ if __name__ == "__main__":
 
         raw_input('next:')
 
-        plt.clf()
+        # 2014-03-10 
+        if mac == 1:
+            plt.close()
+            fig = plt.figure(facecolor='white', figsize=(10, 8))
+        else:
+            plt.clf()
+
         ax1 = fig.add_subplot(111)
         ax2 = fig.add_axes([0.85, 0.11, 0.03, 0.78])
         cb1 = mpl.colorbar.ColorbarBase(ax2, cmap=mycmap, norm=norm, orientation='vertical', ticks=[0.94, 0.96, 0.98, 1.00, 1.02, 1.04, 1.06])
